@@ -1,6 +1,6 @@
 -- 
 -- Created by SQL::Translator::Producer::SQLite
--- Created on Thu May 17 21:26:51 2012
+-- Created on Sat May 26 10:58:55 2012
 -- 
 
 BEGIN TRANSACTION;
@@ -50,7 +50,7 @@ DROP TABLE Bar;
 CREATE TABLE Bar (
   id INTEGER PRIMARY KEY NOT NULL,
   foo_id  NOT NULL,
-  FOREIGN KEY(foo_id) REFERENCES Foo(id)
+  FOREIGN KEY (foo_id) REFERENCES Foo(id) ON DELETE CASCADE ON UPDATE CASCADE
 );
 
 CREATE INDEX Bar_idx_foo_id ON Bar (foo_id);
@@ -64,7 +64,7 @@ CREATE TABLE Foo (
   id  NOT NULL,
   bar_id integer NOT NULL,
   PRIMARY KEY (id),
-  FOREIGN KEY(bar_id) REFERENCES Bar(id)
+  FOREIGN KEY (bar_id) REFERENCES Bar(id) ON DELETE CASCADE ON UPDATE CASCADE
 );
 
 CREATE INDEX Foo_idx_bar_id ON Foo (bar_id);
@@ -78,8 +78,8 @@ CREATE TABLE Foo_Bar (
   foo_id  NOT NULL,
   bar_id integer(12) NOT NULL,
   PRIMARY KEY (foo_id, bar_id),
-  FOREIGN KEY(bar_id) REFERENCES Bar(id),
-  FOREIGN KEY(foo_id) REFERENCES Foo(id)
+  FOREIGN KEY (bar_id) REFERENCES Bar(id),
+  FOREIGN KEY (foo_id) REFERENCES Foo(id)
 );
 
 CREATE INDEX Foo_Bar_idx_bar_id ON Foo_Bar (bar_id);
@@ -95,8 +95,8 @@ CREATE TABLE Gnarly_Station (
   gnarly_id integer NOT NULL,
   station_id integer NOT NULL,
   PRIMARY KEY (gnarly_id, station_id),
-  FOREIGN KEY(gnarly_id) REFERENCES Gnarly(id),
-  FOREIGN KEY(station_id) REFERENCES Station(id)
+  FOREIGN KEY (gnarly_id) REFERENCES Gnarly(id) ON DELETE CASCADE ON UPDATE CASCADE,
+  FOREIGN KEY (station_id) REFERENCES Station(id) ON DELETE CASCADE ON UPDATE CASCADE
 );
 
 CREATE INDEX Gnarly_Station_idx_gnarly_id ON Gnarly_Station (gnarly_id);
